@@ -4,7 +4,7 @@ from django.db import models
 
 class Collection(models.Model):
 
-    name = models.CharField(max_length=127)
+    name = models.CharField(max_length=127, unique=True)
 
     def __str__(self):
         return f'{self.name} ({self.pk})'
